==> haskell-monad-dijkstra-0.1.1.5-183.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-gta9FhokqxBKrZs41z2vf
key:                  monad-dijkstra-0.1.1.5-gta9FhokqxBKrZs41z2vf
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  be866d190d7d6a7d9292a8a1260332a6
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-gta9FhokqxBKrZs41z2vf
depends:
    base-4.18.2.1 containers-0.6.7 free-5.2-3fckYVSYEwRA3sQVkSQiQV
    mtl-2.3.1 psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-dijkstra-0.1.1.5-184-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-J0E2HYyIDK76oipfKwBO1x
key:                  monad-dijkstra-0.1.1.5-J0E2HYyIDK76oipfKwBO1x
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  2995efc66b0668bfe32ede7f850b9dd0
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-J0E2HYyIDK76oipfKwBO1x
depends:
    base-4.18.2.1 containers-0.6.7 free-5.2-CP2SAI6deNWCXG1eD5QmMc
    mtl-2.3.1 psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
